@@ -2,7 +2,7 @@
     chips.c - Part of sensors, a user-space program for hardware monitoring
     Copyright (C) 1998-2003  Frodo Looijaard <frodol@dds.nl> and
                              Mark D. Studebaker <mdsxyz123@yahoo.com>
-    Copyright (C) 2007-2010  Jean Delvare <khali@linux-fr.org>
+    Copyright (C) 2007-2012  Jean Delvare <jdelvare@suse.de>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -115,7 +115,7 @@ static int get_label_size(const sensors_chip_name *name)
 	int i;
 	const sensors_feature *iter;
 	char *label;
-	unsigned int max_size = 11;	/* 11 as minumum label width */
+	unsigned int max_size = 11;	/* 11 as minimum label width */
 
 	i = 0;
 	while ((iter = sensors_get_features(name, &i))) {
@@ -237,6 +237,16 @@ static void get_sensor_limit_data(const sensors_chip_name *name,
 	}
 }
 
+static const struct sensor_subfeature_list temp_min_sensors[] = {
+	{ SENSORS_SUBFEATURE_TEMP_MIN_HYST, NULL, 0, hyst_str },
+	{ -1, NULL, 0, NULL }
+};
+
+static const struct sensor_subfeature_list temp_lcrit_sensors[] = {
+	{ SENSORS_SUBFEATURE_TEMP_LCRIT_HYST, NULL, 0, hyst_str },
+	{ -1, NULL, 0, NULL }
+};
+
 static const struct sensor_subfeature_list temp_max_sensors[] = {
 	{ SENSORS_SUBFEATURE_TEMP_MAX_HYST, NULL, 0, hyst_str },
 	{ -1, NULL, 0, NULL }
@@ -260,9 +270,9 @@ static const struct sensor_subfeature_list temp_sensors[] = {
 	{ SENSORS_SUBFEATURE_TEMP_MAX_ALARM, NULL, 1, "HIGH" },
 	{ SENSORS_SUBFEATURE_TEMP_CRIT_ALARM, NULL, 1, "CRIT" },
 	{ SENSORS_SUBFEATURE_TEMP_EMERGENCY_ALARM, NULL, 1, "EMERGENCY" },
-	{ SENSORS_SUBFEATURE_TEMP_MIN, NULL, 0, "low" },
+	{ SENSORS_SUBFEATURE_TEMP_MIN, temp_min_sensors, 0, "low" },
 	{ SENSORS_SUBFEATURE_TEMP_MAX, temp_max_sensors, 0, "high" },
-	{ SENSORS_SUBFEATURE_TEMP_LCRIT, NULL, 0, "crit low" },
+	{ SENSORS_SUBFEATURE_TEMP_LCRIT, temp_lcrit_sensors, 0, "crit low" },
 	{ SENSORS_SUBFEATURE_TEMP_CRIT, temp_crit_sensors, 0, "crit" },
 	{ SENSORS_SUBFEATURE_TEMP_EMERGENCY, temp_emergency_sensors, 0,
 	    "emerg" },
@@ -658,6 +668,27 @@ static void print_chip_vid(const sensors_chip_name *name,
 	free(label);
 }
 
+static void print_chip_humidity(const sensors_chip_name *name,
+				const sensors_feature *feature,
+				int label_size)
+{
+	char *label;
+	const sensors_subfeature *subfeature;
+	double humidity;
+
+	subfeature = sensors_get_subfeature(name, feature,
+					    SENSORS_SUBFEATURE_HUMIDITY_INPUT);
+	if (!subfeature)
+		return;
+
+	if ((label = sensors_get_label(name, feature))
+	 && !sensors_get_value(name, subfeature->number, &humidity)) {
+		print_label(label, label_size);
+		printf("%6.1f %%RH\n", humidity);
+	}
+	free(label);
+}
+
 static void print_chip_beep_enable(const sensors_chip_name *name,
 				   const sensors_feature *feature,
 				   int label_size)
@@ -792,6 +823,9 @@ void print_chip(const sensors_chip_name *name)
 		case SENSORS_FEATURE_INTRUSION:
 			print_chip_intrusion(name, feature, label_size);
 			break;
+		case SENSORS_FEATURE_HUMIDITY:
+			print_chip_humidity(name, feature, label_size);
+			break;
 		default:
 			continue;
 		}
